<?php
// Initialisation de la session
session_start();

// Variable contenant la page où l'on souhaite aller une fois connecté
$chatPage = "chat.php";

// On vérifie si l'utilisateur et loggué : 
    // - si oui : on le redirige sur le chat,
    // - si non : affichage du formulaire
if(isset($_SESSION["connecte"]) && $_SESSION["connecte"] === true) {
  header("location: $chatPage");
  exit;
}

// Inclusion du fichier de config
require_once "config.php";

// Definition des variables et intialisation avec des valeurs vides
$username = $password = "";
$username_err = $password_err = "";
 
// Test (if) : est-ce que l'on vient de poster des infos de connexion ?
// via le formulaire
//if (isset($_POST["username"]) && isset($_POST["password"]) &&
//    !empty($_POST["username"]) && !empty($_POST["password"]))

// Initialisation d'un message d'erreur
$msg_err = "";

if($_SERVER["REQUEST_METHOD"] == "POST") {
 
    // Check if username is empty
    if(empty(trim($_POST["username"]))){
        $username_err = "Entrez un nom d'utilisateur.";
    } else {
        $username = trim($_POST["username"]);
    }
    
    // Check if password is empty
    if(empty(trim($_POST["password"]))) {
        $password_err = "Entrez votre mot de passe.";
    } else {
        $password = trim($_POST["password"]);
    }
    
    // Validate credentials
    if(empty($username_err) && empty($password_err)) {
        try {
            $dbh = connect_db();
            // On Récupère les identifiants de l'utilisateur
            $sql = "SELECT id, username, password FROM users WHERE username = :username";
            $requete = $dbh->prepare($sql);
            $requete->bindParam(':username', $username);
            $requete->execute();

            // Check if username exists, if yes then verify password
            if($requete->rowCount() == 1) {
                // Bind result variables
                $result = $requete->fetch();
                if(password_verify($password, $result['password'])) {
                    // Password is correct, so start a new session
                    session_start();
                    
                    // On stocke les infos dans la variables $_SESSION
                    // - connecte qui permet de faire le test : est-on connecté ?
                    // - username qui permet de garder le nom/pseudo de connexion
                    $_SESSION["connecte"] = true;
                    $_SESSION["username"] = $username;
                    
                    // Redirection vers la page du connected
                    header("location: $chatPage");
                } else {
                    // Display an error message if password is not valid
                    $password_err = "Le mot de passe fourni n'est pas valide.";
                }
            } else {
                // Display an error message if username doesn't exist
                $username_err = "Nom d'utilisateur inexistant.";
            }

            // Close connection
            $dbh = null;

        }
        catch (PDOException $e) {
            $msg_err = "Impossible de se connecter correctement à la base de données, désolé ...<br />Le chat ne pourra pas fonctionner";
        }
    }
}
?>
 
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Login</title>
     <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.css">
    <style type="text/css">
        body{ font: 14px sans-serif; }
        .wrapper{ width: 350px; padding: 20px; }
    </style>
    <!-- <link rel="stylesheet" href="css/app.css"> -->
</head>
<body>
    <?php if (!empty($msg_err)) { ?>
        <?php echo "<div class=\"alert alert-danger\"><strong>Problème de fonctionnement :</strong><br />$msg_err</div>";
    } ?>

    <div class="wrapper">
        <h2>Connexion</h2>
        <p>Remplisser les identifiants pour vous connecter.</p>
        <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post">
            <div class="form-group <?php echo (!empty($username_err)) ? 'has-error' : ''; ?>">
                <label>Nom / pseudo</label>
                <input type="text" name="username" class="form-control" value="<?php echo $username; ?>">
                <span class="help-block"><?php echo $username_err; ?></span>
            </div>    
            <div class="form-group <?php echo (!empty($password_err)) ? 'has-error' : ''; ?>">
                <label>Mot de passe</label>
                <input type="password" name="password" class="form-control">
                <span class="help-block"><?php echo $password_err; ?></span>
            </div>
            <div class="form-group">
                <input type="submit" class="btn btn-primary" value="Connexion">
            </div>
            <p>Vous n'avez pas de compte ? <a href="register.php">Créez en un ici</a>.</p>
        </form>
    </div>    
</body>
</html>