<?php
// Include config file
require_once "config.php";
 
// Define variables and initialize with empty values
$username = $password = $confirm_password = $question = "";
$username_err = $password_err = $confirm_password_err = $question_err = "";
 
// Processing form data when form is submitted
if($_SERVER["REQUEST_METHOD"] == "POST") {

    try {
        $dbh = connect_db();

        // Validate username
        if(empty(trim($_POST["username"]))) {
            $username_err = "Entrez un nom d'utilisateur.";
        } else {
            $username = trim($_POST["username"]);
            // Liste des utilisateurs enregistrés
            $sql = "SELECT id FROM users WHERE username = :username";
            // Création d'un PDO::statement
            $requete = $dbh->prepare($sql);
            $requete->bindParam(':username', $username);
            $requete->execute();
                
            if($requete->rowCount() == 1){
                $username_err = "This username is already taken.";
            } 
            
        }
        
        // Validate password
        if(empty(trim($_POST["password"]))) {
            $password_err = "Please enter a password.";     
        } elseif(strlen(trim($_POST["password"])) < 6) {
            $password_err = "Password must have atleast 6 characters.";
        } else {
            $password = trim($_POST["password"]);
        }
        
        // Validate confirm password
        if(empty(trim($_POST["confirm_password"]))) {
            $confirm_password_err = "Confirmer le mot de passe.";     
        } else {
            $confirm_password = trim($_POST["confirm_password"]);        
            if(empty($password_err) && ($password != $confirm_password)) {
                $confirm_password_err = "Les mots de passe ne correspondent pas.";
            }
        }
        
        // Validate captcha
        if(empty(trim($_POST["question"]))) {
            $question_err = "Répondez à la question SVP !";     
        } else {
            $question = trim($_POST["question"]);        
            if(!preg_match("/corsaire/i", $question)) {
                $question_err = "Il vous manque la clef !";
            }
        }


        // Check input errors before inserting in database
        if(empty($username_err) && empty($password_err) && empty($confirm_password_err)) { 
            // Créé un hash du mot de passe pour ne pas le stocker en clair dans la base
            $h_pwd = password_hash($password, PASSWORD_DEFAULT);
            
            // Prepare an insert statement
            $sql = "INSERT INTO users (username, password) VALUES (:username, :password)";
            // Création d'un PDO::statement
            $requete = $dbh->prepare($sql);
            $requete->bindParam(':username', $username);
            $requete->bindParam(':password', $h_pwd);
            
            $requete->execute();
            
            // Redirect to login page
            header("location: index.php");
        }

        // Close statement
        $dbh = null;
    } catch (PDOException $e) {
        // Redirect to login page
        header("location: index.php");
    }
}
?>
 
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Sign Up</title>
    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.css">
    <style type="text/css">
        body{ font: 14px sans-serif; }
        .wrapper{ width: 350px; padding: 20px; }
    </style>
</head>
<body>
    <div class="wrapper">
        <h2>Enregistrez vous</h2>
        <p>Remplissez le formulaire pour créer un compte.</p>
        <form action="<?php echo htmlspecialchars($_SERVER["PHP_SELF"]); ?>" method="post">
            <div class="form-group <?php echo (!empty($username_err)) ? 'has-error' : ''; ?>">
                <label>Nom /pseuso</label>
                <input type="text" name="username" class="form-control" value="<?php echo $username; ?>">
                <span class="help-block"><?php echo $username_err; ?></span>
            </div>    
            <div class="form-group <?php echo (!empty($password_err)) ? 'has-error' : ''; ?>">
                <label>Mot de passe</label>
                <input type="password" name="password" class="form-control" value="<?php echo $password; ?>">
                <span class="help-block"><?php echo $password_err; ?></span>
            </div>
            <div class="form-group <?php echo (!empty($confirm_password_err)) ? 'has-error' : ''; ?>">
                <label>Confirmer le mot de passe</label>
                <input type="password" name="confirm_password" class="form-control" value="<?php echo $confirm_password; ?>">
                <span class="help-block"><?php echo $confirm_password_err; ?></span>
            </div>
            <div class="form-group <?php echo (!empty($question_err)) ? 'has-error' : ''; ?>">
                <label>Indiquer le nom des étudiants de l'IMTS</label>
                <input type="text" name="question" class="form-control" value="<?php echo $question; ?>">
                <span class="help-block"><?php echo $question_err; ?></span>
            </div>
            <div class="form-group">
                <input type="submit" class="btn btn-primary" value="Envoyer">
                <input type="reset" class="btn btn-default" value="Reset">
            </div>
            <p>Vous avez déjà un compte ? <a href="index.php">Page de connexion</a>.</p>
        </form>
    </div>    
</body>
</html>